Class: Aws::ApplicationAutoScaling::Types::DescribeScheduledActionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationautoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token required to get the next set of results. This value is null if there are no more results to return.



1634
1635
1636
1637
1638
1639
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 1634

class DescribeScheduledActionsResponse < Struct.new(
  :scheduled_actions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_actionsArray<Types::ScheduledAction>

Information about the scheduled actions.



1634
1635
1636
1637
1638
1639
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 1634

class DescribeScheduledActionsResponse < Struct.new(
  :scheduled_actions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end