Class: Aws::ApplicationAutoScaling::Types::PredefinedMetricSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationAutoScaling::Types::PredefinedMetricSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationautoscaling/types.rb
Overview
Represents a predefined metric for a target tracking scaling policy to use with Application Auto Scaling.
For more information, [Predefined metrics for target tracking scaling policies] in the *Application Auto Scaling User Guide*.
[1]: docs.aws.amazon.com/autoscaling/application/userguide/monitoring-cloudwatch.html#predefined-metrics
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#predefined_metric_type ⇒ String
The metric type.
-
#resource_label ⇒ String
Identifies the resource associated with the metric type.
Instance Attribute Details
#predefined_metric_type ⇒ String
The metric type. The following are notes about specific metric types:
-
‘ALBRequestCountPerTarget` - This metric type applies only to Spot Fleets and ECS services.
-
‘ECSServiceAverageCPUUtilizationHighResolution` - The high-resolution version of `ECSServiceAverageCPUUtilization` that uses 20-second CloudWatch metrics. Use this metric for target tracking scaling policies that evaluate metrics every 20 seconds. You must enable high-resolution metrics in Amazon ECS before creating a scaling policy with this metric type.
-
‘ECSServiceAverageMemoryUtilizationHighResolution` - The high-resolution version of `ECSServiceAverageMemoryUtilization` that uses 20-second CloudWatch metrics. Use this metric for target tracking scaling policies that evaluate metrics every 20 seconds. You must enable high-resolution metrics in Amazon ECS before creating a scaling policy with this metric type.
1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 1977 class PredefinedMetricSpecification < Struct.new( :predefined_metric_type, :resource_label) SENSITIVE = [] include Aws::Structure end |
#resource_label ⇒ String
Identifies the resource associated with the metric type. You can’t specify a resource label unless the metric type is ‘ALBRequestCountPerTarget` and there is a target group attached to the Spot Fleet or ECS service.
You create the resource label by appending the final portion of the load balancer ARN and the final portion of the target group ARN into a single value, separated by a forward slash (/). The format of the resource label is:
‘app/my-alb/778d41231b141a0f/targetgroup/my-alb-target-group/943f017f100becff`.
Where:
-
app/<load-balancer-name>/<load-balancer-id> is the final portion of the load balancer ARN
-
targetgroup/<target-group-name>/<target-group-id> is the final portion of the target group ARN.
To find the ARN for an Application Load Balancer, use the
- DescribeLoadBalancers][1
-
API operation. To find the ARN for the
target group, use the [DescribeTargetGroups] API operation.
[1]: docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancers.html [2]: docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroups.html
1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 1977 class PredefinedMetricSpecification < Struct.new( :predefined_metric_type, :resource_label) SENSITIVE = [] include Aws::Structure end |