Class: Aws::ApplicationAutoScaling::Types::PredictiveScalingMetricSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationautoscaling/types.rb

Overview

This structure specifies the metrics and target utilization settings for a predictive scaling policy.

You must specify either a metric pair, or a load metric and a scaling metric individually. Specifying a metric pair instead of individual metrics provides a simpler way to configure metrics for a scaling policy. You choose the metric pair, and the policy automatically knows the correct sum and average statistics to use for the load metric and the scaling metric.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customized_capacity_metric_specificationTypes::PredictiveScalingCustomizedMetricSpecification

The customized capacity metric specification.



2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2149

class PredictiveScalingMetricSpecification < Struct.new(
  :target_value,
  :predefined_metric_pair_specification,
  :predefined_scaling_metric_specification,
  :predefined_load_metric_specification,
  :customized_scaling_metric_specification,
  :customized_load_metric_specification,
  :customized_capacity_metric_specification)
  SENSITIVE = []
  include Aws::Structure
end

#customized_load_metric_specificationTypes::PredictiveScalingCustomizedMetricSpecification

The customized load metric specification.



2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2149

class PredictiveScalingMetricSpecification < Struct.new(
  :target_value,
  :predefined_metric_pair_specification,
  :predefined_scaling_metric_specification,
  :predefined_load_metric_specification,
  :customized_scaling_metric_specification,
  :customized_load_metric_specification,
  :customized_capacity_metric_specification)
  SENSITIVE = []
  include Aws::Structure
end

#customized_scaling_metric_specificationTypes::PredictiveScalingCustomizedMetricSpecification

The customized scaling metric specification.



2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2149

class PredictiveScalingMetricSpecification < Struct.new(
  :target_value,
  :predefined_metric_pair_specification,
  :predefined_scaling_metric_specification,
  :predefined_load_metric_specification,
  :customized_scaling_metric_specification,
  :customized_load_metric_specification,
  :customized_capacity_metric_specification)
  SENSITIVE = []
  include Aws::Structure
end

#predefined_load_metric_specificationTypes::PredictiveScalingPredefinedLoadMetricSpecification

The predefined load metric specification.



2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2149

class PredictiveScalingMetricSpecification < Struct.new(
  :target_value,
  :predefined_metric_pair_specification,
  :predefined_scaling_metric_specification,
  :predefined_load_metric_specification,
  :customized_scaling_metric_specification,
  :customized_load_metric_specification,
  :customized_capacity_metric_specification)
  SENSITIVE = []
  include Aws::Structure
end

#predefined_metric_pair_specificationTypes::PredictiveScalingPredefinedMetricPairSpecification

The predefined metric pair specification that determines the appropriate scaling metric and load metric to use.



2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2149

class PredictiveScalingMetricSpecification < Struct.new(
  :target_value,
  :predefined_metric_pair_specification,
  :predefined_scaling_metric_specification,
  :predefined_load_metric_specification,
  :customized_scaling_metric_specification,
  :customized_load_metric_specification,
  :customized_capacity_metric_specification)
  SENSITIVE = []
  include Aws::Structure
end

#predefined_scaling_metric_specificationTypes::PredictiveScalingPredefinedScalingMetricSpecification

The predefined scaling metric specification.



2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2149

class PredictiveScalingMetricSpecification < Struct.new(
  :target_value,
  :predefined_metric_pair_specification,
  :predefined_scaling_metric_specification,
  :predefined_load_metric_specification,
  :customized_scaling_metric_specification,
  :customized_load_metric_specification,
  :customized_capacity_metric_specification)
  SENSITIVE = []
  include Aws::Structure
end

#target_valueFloat

Specifies the target utilization.

Returns:

  • (Float)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2149

class PredictiveScalingMetricSpecification < Struct.new(
  :target_value,
  :predefined_metric_pair_specification,
  :predefined_scaling_metric_specification,
  :predefined_load_metric_specification,
  :customized_scaling_metric_specification,
  :customized_load_metric_specification,
  :customized_capacity_metric_specification)
  SENSITIVE = []
  include Aws::Structure
end