Class: Aws::ApplicationAutoScaling::Types::PredictiveScalingPredefinedMetricPairSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationautoscaling/types.rb

Overview

Represents a metric pair for a predictive scaling policy.

The following predefined metrics are available for predictive scaling:

  • ‘ECSServiceAverageCPUUtilization`

  • ‘ECSServiceAverageMemoryUtilization`

  • ‘ECSServiceCPUUtilization`

  • ‘ECSServiceMemoryUtilization`

  • ‘ECSServiceTotalCPUUtilization`

  • ‘ECSServiceTotalMemoryUtilization`

  • ‘ALBRequestCount`

  • ‘ALBRequestCountPerTarget`

  • ‘TotalALBRequestCount`

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#predefined_metric_typeString

Indicates which metrics to use. There are two different types of metrics for each metric type: one is a load metric and one is a scaling metric.

Returns:

  • (String)


2325
2326
2327
2328
2329
2330
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2325

class PredictiveScalingPredefinedMetricPairSpecification < Struct.new(
  :predefined_metric_type,
  :resource_label)
  SENSITIVE = []
  include Aws::Structure
end

#resource_labelString

A label that uniquely identifies a specific target group from which to determine the total and average request count.

Returns:

  • (String)


2325
2326
2327
2328
2329
2330
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2325

class PredictiveScalingPredefinedMetricPairSpecification < Struct.new(
  :predefined_metric_type,
  :resource_label)
  SENSITIVE = []
  include Aws::Structure
end