Class: Aws::ApplicationAutoScaling::Types::PredictiveScalingPredefinedScalingMetricSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationautoscaling/types.rb

Overview

Describes a scaling metric for a predictive scaling policy.

When returned in the output of ‘DescribePolicies`, it indicates that a predictive scaling policy uses individually specified load and scaling metrics instead of a metric pair.

The following predefined metrics are available for predictive scaling:

  • ‘ECSServiceAverageCPUUtilization`

  • ‘ECSServiceAverageMemoryUtilization`

  • ‘ECSServiceCPUUtilization`

  • ‘ECSServiceMemoryUtilization`

  • ‘ECSServiceTotalCPUUtilization`

  • ‘ECSServiceTotalMemoryUtilization`

  • ‘ALBRequestCount`

  • ‘ALBRequestCountPerTarget`

  • ‘TotalALBRequestCount`

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#predefined_metric_typeString

The metric type.

Returns:

  • (String)


2369
2370
2371
2372
2373
2374
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2369

class PredictiveScalingPredefinedScalingMetricSpecification < Struct.new(
  :predefined_metric_type,
  :resource_label)
  SENSITIVE = []
  include Aws::Structure
end

#resource_labelString

A label that uniquely identifies a specific target group from which to determine the average request count.

Returns:

  • (String)


2369
2370
2371
2372
2373
2374
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 2369

class PredictiveScalingPredefinedScalingMetricSpecification < Struct.new(
  :predefined_metric_type,
  :resource_label)
  SENSITIVE = []
  include Aws::Structure
end