Class: Aws::ApplicationAutoScaling::Types::UntagResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationautoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

Identifies the Application Auto Scaling scalable target from which to remove tags.

For example: arn:aws:application-autoscaling:us-east-1:123456789012:scalable-target/1234abcd56ab78cd901ef1234567890ab123

To get the ARN for a scalable target, use DescribeScalableTargets.

Returns:

  • (String)


4774
4775
4776
4777
4778
4779
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 4774

class UntagResourceRequest < Struct.new(
  :resource_arn,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end

#tag_keysArray<String>

One or more tag keys. Specify only the tag keys, not the tag values.

Returns:

  • (Array<String>)


4774
4775
4776
4777
4778
4779
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 4774

class UntagResourceRequest < Struct.new(
  :resource_arn,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end