Class: Aws::ApplicationAutoScaling::Types::UntagResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationAutoScaling::Types::UntagResourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationautoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
Identifies the Application Auto Scaling scalable target from which to remove tags.
-
#tag_keys ⇒ Array<String>
One or more tag keys.
Instance Attribute Details
#resource_arn ⇒ String
Identifies the Application Auto Scaling scalable target from which to remove tags.
For example: arn:aws:application-autoscaling:us-east-1:123456789012:scalable-target/1234abcd56ab78cd901ef1234567890ab123
To get the ARN for a scalable target, use DescribeScalableTargets.
4774 4775 4776 4777 4778 4779 |
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 4774 class UntagResourceRequest < Struct.new( :resource_arn, :tag_keys) SENSITIVE = [] include Aws::Structure end |
#tag_keys ⇒ Array<String>
One or more tag keys. Specify only the tag keys, not the tag values.
4774 4775 4776 4777 4778 4779 |
# File 'lib/aws-sdk-applicationautoscaling/types.rb', line 4774 class UntagResourceRequest < Struct.new( :resource_arn, :tag_keys) SENSITIVE = [] include Aws::Structure end |